@@ -44,21 +44,25 @@ try:
 except ImportError:
     import random
 
-if 'pydevd' not in sys.modules:
-    try:
-        import grequests
-    except ImportError:
-        pass
-    except NotImplementedError:
-        pass
-
-warnings.simplefilter('default')
+# warnings.simplefilter('default')
 
 #encoding = sys.getdefaultencoding()
 # if encoding != 'UTF8':
 #    warnings.warn("Python default encoding is '%s' instead of 'UTF8' which means that there is a big change of having problems. Possible workaround http://stackoverflow.com/a/17628350/99834" % encoding)
 
 
+def threaded_requests(requests):
+    for fn, url, request_args in requests:
+        th = threading.Thread(
+            target=fn, args=(url,), kwargs=request_args, name=url,
+        )
+        th.start()
+
+    for th in threading.enumerate():
+        if th.name.startswith('http'):
+            th.join()
+
+
 def translate_resource_args(func):
     """
     Decorator that converts Issue and Project resources to their keys when used as arguments.
@@ -244,7 +248,7 @@ class JIRA(object):
         """
         if hasattr(self._session, '_async_jobs'):
             logging.info("Executing async %s jobs found in queue by using %s threads..." % (len(self._session._async_jobs), size))
-            grequests.map(self._session._async_jobs, size=size)
+            threaded_requests.map(self._session._async_jobs, size=size)
 
 # Application properties
 
@@ -910,7 +914,7 @@ class JIRA(object):
         return self._find_for_resource(Worklog, (issue, id))
 
     @translate_resource_args
-    def add_worklog(self, issue, timeSpent=None, adjustEstimate=None,
+    def add_worklog(self, issue, timeSpent=None, timeSpentSeconds=None, adjustEstimate=None,
                     newEstimate=None, reduceBy=None, comment=None, started=None, user=None):
         """
         Add a new worklog entry on an issue and return a Resource for it.
@@ -935,6 +939,8 @@ class JIRA(object):
         data = {}
         if timeSpent is not None:
             data['timeSpent'] = timeSpent
+        if timeSpentSeconds is not None:
+            data['timeSpentSeconds'] = timeSpentSeconds
         if comment is not None:
             data['comment'] = comment
         elif user:
@@ -1790,63 +1796,80 @@ class JIRA(object):
         :param new_user: string with username login
         """
 
-        merge = "true"
-        try:
-            self.user(new_user)
-        except:
-            merge = "false"
+        if self._version >= (6, 0, 0):
 
-        url = self._options['server'] + '/secure/admin/groovy/CannedScriptRunner.jspa#result'
-        payload = {
-            "cannedScript": "com.onresolve.jira.groovy.canned.admin.RenameUser",
-            "cannedScriptArgs_FIELD_FROM_USER_ID": old_user,
-            "cannedScriptArgs_FIELD_TO_USER_ID": new_user,
-            "cannedScriptArgs_FIELD_MERGE": merge,
-            "id": "",
-            "RunCanned": "Run",
-        }
+            url = self._options['server'] + '/rest/api/2/user'
+            payload = {
+                "name": new_user,
+            }
+            params = {
+                'username': old_user
+            }
 
-        logging.debug("renaming %s" % self.user(old_user).emailAddress)  # raw displayName
+            logging.debug("renaming %s" % self.user(old_user).emailAddress)  # raw displayName
 
-        r = self._session.post(url, headers=self._options['headers'], data=payload)
-        if r.status_code == 404:
-            logging.error("In order to be able to use rename_user() you need to install Script Runner plugin. See https://marketplace.atlassian.com/plugins/com.onresolve.jira.groovy.groovyrunner")
-            return False
-        if r.status_code != 200:
-            logging.error(r.status_code)
+            r = self._session.put(url, params=params, headers={'content-type': 'application/json'}, data=json.dumps(payload))
+            raise_on_error(r)
 
-        raise_on_error(r)
+        else:
+            # old implementation needed the ScripRunner plugin
+            merge = "true"
+            try:
+                self.user(new_user)
+            except:
+                merge = "false"
 
-        if re.compile("XSRF Security Token Missing").search(r.text):
-            logging.fatal("Reconfigure JIRA and disable XSRF in order to be able call this. See https://developer.atlassian.com/display/JIRADEV/Form+Token+Handling")
-            return False
+            url = self._options['server'] + '/secure/admin/groovy/CannedScriptRunner.jspa#result'
+            payload = {
+                "cannedScript": "com.onresolve.jira.groovy.canned.admin.RenameUser",
+                "cannedScriptArgs_FIELD_FROM_USER_ID": old_user,
+                "cannedScriptArgs_FIELD_TO_USER_ID": new_user,
+                "cannedScriptArgs_FIELD_MERGE": merge,
+                "id": "",
+                "RunCanned": "Run",
+            }
 
-        open("/tmp/jira_rename_user_%s_to%s.html" % (old_user, new_user), "w").write(r.text)
+            logging.debug("renaming %s" % self.user(old_user).emailAddress)  # raw displayName
+
+            r = self._session.post(url, headers=self._options['headers'], data=payload)
+            if r.status_code == 404:
+                logging.error("In order to be able to use rename_user() you need to install Script Runner plugin. See https://marketplace.atlassian.com/plugins/com.onresolve.jira.groovy.groovyrunner")
+                return False
+            if r.status_code != 200:
+                logging.error(r.status_code)
+
+            raise_on_error(r)
+
+            if re.compile("XSRF Security Token Missing").search(r.content):
+                logging.fatal("Reconfigure JIRA and disable XSRF in order to be able call this. See https://developer.atlassian.com/display/JIRADEV/Form+Token+Handling")
+                return False
+
+            open("/tmp/jira_rename_user_%s_to%s.html" % (old_user, new_user), "w").write(r.content)
+
+            msg = r.status_code
+            m = re.search("<span class=\"errMsg\">(.*)<\/span>", r.content)
+            if m:
+                msg = m.group(1)
+                logging.error(msg)
+                return False
+                # <span class="errMsg">Target user ID must exist already for a merge</span>
+            p = re.compile("type=\"hidden\" name=\"cannedScriptArgs_Hidden_output\" value=\"(.*?)\"\/>", re.MULTILINE | re.DOTALL)
+            m = p.search(r.content)
+            if m:
+                h = HTMLParser.HTMLParser()
+                msg = h.unescape(m.group(1))
+                logging.info(msg)
+
+            # let's check if the user still exists
+            try:
+                self.user(old_user)
+            except:
+                logging.error("User %s does not exists." % old_user)
+                return msg
 
-        msg = r.status_code
-        m = re.search("<span class=\"errMsg\">(.*)<\/span>", r.text)
-        if m:
-            msg = m.group(1)
             logging.error(msg)
+            logging.error("User %s does still exists after rename, that's clearly a problem." % old_user)
             return False
-            # <span class="errMsg">Target user ID must exist already for a merge</span>
-        p = re.compile("type=\"hidden\" name=\"cannedScriptArgs_Hidden_output\" value=\"(.*?)\"\/>", re.MULTILINE | re.DOTALL)
-        m = p.search(r.text)
-        if m:
-            h = HTMLParser.HTMLParser()
-            msg = h.unescape(m.group(1))
-            logging.info(msg)
-
-        # let's check if the user still exists
-        try:
-            self.user(old_user)
-        except:
-            logging.error("User %s does not exists." % old_user)
-            return msg
-
-        logging.error(msg)
-        logging.error("User %s does still exists after rename, that's clearly a problem." % old_user)
-        return False
 
     def delete_user(self, username):
 
